@@ -14,7 +14,7 @@ class PartitionFilter(NetBoxModelFilterSet):
 
     class Meta:
         model = Partition
-        fields = ("device", "size", "type")
+        fields = ['drive', 'size', 'fs_type', 'letter', 'description']
 
     def search(self, queryset, name, value):
         """Perform the filtered search."""
@@ -22,6 +22,7 @@ class PartitionFilter(NetBoxModelFilterSet):
             return queryset
         qs_filter = (
             Q(size__icontains=value)
-            | Q(device__icontains=value)
+            | Q(letter__icontains=value)
+            | Q(description__icontains=value)
         )
         return queryset.filter(qs_filter)
